@@ -3,7 +3,7 @@ try:
 except ImportError:
     pass  # not jupyter.
 
-import json, re, os, pickle
+import json, re, os, pickle, requests
 from warnings import warn
 from typing import Any
 from datetime import datetime
@@ -142,7 +142,8 @@ class MikePage(TableMixin):
 
     def __setattr__(self, attr, value) -> None:
         ## Accepts custom fields. Messes up @property, so it is done manually.
-        dynamics = {'columns_viewport': self._set_columns_viewport, 'columns_text': self._set_columns_text}
+        dynamics = {'columns_viewport': self._set_columns_viewport,
+                    'columns_text': self._set_columns_text}
         if attr in dynamics.keys():
             dynamics[attr].__call__(value)
         elif attr in self.preferences and not isinstance(value, self.preferences[attr]):
@@ -364,8 +365,8 @@ class MikePage(TableMixin):
                     name: Optional[str] = None,
                     value: Optional[str] = None) -> Dict:
         """
-        Overloaded method. accepts one of the three parameters:
-        
+        Faux-overloaded method. accepts one of the three parameters:
+
         :param index: list index
         :param name: name of protein
         :param value: value of protein, this is the JS function
@@ -446,6 +447,16 @@ class MikePage(TableMixin):
         self.pdbs[varname] = pdbblock
         return len(self.proteins) - 1
 
+    def append_url(self, name: str, url: str, ext: str = 'pdb', verify: bool = True):
+        if verify:  # test url
+            response = requests.get(url)
+            response.raise_for_status()
+        self.proteins.append(dict(name=name,
+                                  type='url',
+                                  ext=ext,
+                                  value=url)
+                             )
+
     def remove_protein(self, index):
         if self.proteins[index]['type'] == 'data':
             del self.pdbs[self.proteins[index]['value']]
@@ -453,6 +464,12 @@ class MikePage(TableMixin):
         del self.proteins[index]
         return d
 
+    def get_pdb_url(self, name):
+        i = self.get_protein(name=name)
+        return f'/save_pdb?uuid={self.page}&key=None&index={i}'
+
+    # ======== Published ===============================================================================================
+
     def add_publication(self,
                         url: Optional[str] = None,
                         authors: Optional[str] = 'TBA',
@@ -465,8 +482,9 @@ class MikePage(TableMixin):
         This is an admin only operation due to the security issue (dodgy links in the gallery).
         Publication is not data from the page, it's an actual table
 
+
         :param uuid:
-        :param url:
+        :param url: If no URL is provided it is generated from DOI
         :param authors:
         :param year:
         :param title:
@@ -491,6 +509,15 @@ class MikePage(TableMixin):
                                              'journal': journal,
                                              'issue': issue})
 
+    def protect(self):
+        return self.parent.post_json('set', {'item': 'protection',
+                                             'page': self.page})
+
+    def deprotect(self):
+        return self.parent.post_json('set', {'item': 'deprotection',
+                                             'page': self.page})
+
+
     # ======== Parent ==================================================================================================
 
     def retrieve(self):
